@@ -445,9 +445,10 @@ namespace TagLib
             return ToLong(true);
         }
 
-        public string ToString(StringType type)
+        public string ToString(StringType type, int offset)
         {
-            string s = StringTypeToEncoding(type, Mid(0, 2)).GetString(Data, 0, Count);
+            ByteVector bom = type == StringType.UTF16 ? Mid(offset, 2) : null;
+            string s = StringTypeToEncoding(type, bom).GetString(Data, offset, Count - offset);
             
             if(s.Length != 0 && (s[0] == 0xfffe || s[0] == 0xfeff)) { // UTF16 BOM
                 return s.Substring(1);
@@ -456,6 +457,11 @@ namespace TagLib
             return s;
         }
 
+        public string ToString(StringType type)
+        {
+            return ToString (type, 0);
+        }
+
         public override string ToString()
         {
             return ToString(StringType.UTF8);
@@ -665,7 +671,7 @@ namespace TagLib
                             firstChunk = new byte[read_size];
                         }
 
-                        Array.Copy(bytes, firstChunk, n);
+                        Array.Copy(bytes, 0, firstChunk, 0, n);
                     }
                     set_first_chunk = true;
                 }
@@ -702,7 +708,15 @@ namespace TagLib
                     return System.Text.Encoding.Unicode;
             }
             
-            return System.Text.Encoding.ASCII;
+            try
+            {
+               // The right format but not ECMA.
+               return System.Text.Encoding.GetEncoding("latin1");
+            }
+            catch
+            {
+               return System.Text.Encoding.UTF8;
+            }
         }
       
         #endregion
